diff --git a/src/main/java/net/minecraft/client/gui/options/components/SearchFieldComponent.java b/src/main/java/net/minecraft/client/gui/options/components/SearchFieldComponent.java
index 741c45317..cb8709867 100644
--- a/src/main/java/net/minecraft/client/gui/options/components/SearchFieldComponent.java
+++ b/src/main/java/net/minecraft/client/gui/options/components/SearchFieldComponent.java
@@ -33,7 +33,7 @@ public class SearchFieldComponent
         textField.setMaxStringLength(20);
         textField.setTextChangeListener(this);
         editor = new TextFieldEditor(textField);
-        clearButton = new ButtonElement(0, 0, 0, 12, 20, "X")
+        clearButton = new ButtonElement(0, 0, 0, 12, 20, "")
             .setTextures("minecraft:gui/screen/options/clear", "minecraft:gui/screen/options/clear_highlighted", null);
     }
 
diff --git a/src/main/java/net/minecraft/client/render/block/model/CrossedSquaresBlockModel.java b/src/main/java/net/minecraft/client/render/block/model/CrossedSquaresBlockModel.java
index d9062f8a6..c5876dba9 100644
--- a/src/main/java/net/minecraft/client/render/block/model/CrossedSquaresBlockModel.java
+++ b/src/main/java/net/minecraft/client/render/block/model/CrossedSquaresBlockModel.java
@@ -47,8 +47,10 @@ public class CrossedSquaresBlockModel<T extends Block> extends StandardBlockMode
         final double maxV = texIndex.getIconVMax();
 
         tessellator.startDrawingQuads();
-        tessellator.setColorOpaque_F(r * brightness, g * brightness, b * brightness);
-        tessellator.setNormal(0.0F, 1.0F, 0.0F);
+        tessellator.setColorRGBA_F(r * brightness, g * brightness, b * brightness, alpha);
+        if (!LightmapHelper.isLightmapEnabled()) { // TODO figure out what the hell is wrong with normals when lightmap is enabled
+            tessellator.setNormal(0.0F, 1.0F, 0.0F);
+        }
         if (LightmapHelper.isLightmapEnabled() && lightmapCoordinate != null){
             tessellator.setLightmapCoord(lightmapCoordinate);
         }
diff --git a/src/main/java/net/minecraft/client/render/blockentity/FlowerJarBlockEntityRenderer.java b/src/main/java/net/minecraft/client/render/blockentity/FlowerJarBlockEntityRenderer.java
index 6fa5c9352..e44caeefe 100644
--- a/src/main/java/net/minecraft/client/render/blockentity/FlowerJarBlockEntityRenderer.java
+++ b/src/main/java/net/minecraft/client/render/blockentity/FlowerJarBlockEntityRenderer.java
@@ -1,6 +1,7 @@
 package net.minecraft.client.render.blockentity;
 
 import net.minecraft.client.Minecraft;
+import net.minecraft.client.render.Lighting;
 import net.minecraft.client.render.LightmapHelper;
 import net.minecraft.client.render.RenderBlocks;
 import net.minecraft.client.render.block.model.BlockModel;
@@ -14,6 +15,19 @@ import net.minecraft.core.enums.LightLayer;
 import net.minecraft.core.world.World;
 import org.lwjgl.opengl.GL11;
 
+import java.util.Map;
+
+import static org.lwjgl.opengl.GL11.GL_BLEND;
+import static org.lwjgl.opengl.GL11.GL_COLOR_MATERIAL;
+import static org.lwjgl.opengl.GL11.GL_FLAT;
+import static org.lwjgl.opengl.GL11.GL_LIGHT0;
+import static org.lwjgl.opengl.GL11.GL_LIGHT1;
+import static org.lwjgl.opengl.GL11.GL_LIGHTING;
+import static org.lwjgl.opengl.GL11.GL_ONE_MINUS_SRC_ALPHA;
+import static org.lwjgl.opengl.GL11.GL_SRC_ALPHA;
+import static org.lwjgl.opengl.GL11.glEnable;
+import static org.lwjgl.opengl.GL11.glShadeModel;
+
 public class FlowerJarBlockEntityRenderer extends BlockEntityRenderer<FlowerJarBlockEntity> {
     private RenderBlocks renderBlocks;
     @Override
@@ -24,14 +38,14 @@ public class FlowerJarBlockEntityRenderer extends BlockEntityRenderer<FlowerJarB
     @Override
     public void doRender(Tessellator tessellator, FlowerJarBlockEntity tileEntity, double x, double y, double z, float renderPartialTicks) {
         GL11.glPushMatrix();
-        if(tileEntity.flowerInPot > 0){
+        Block block = Block.getBlock(tileEntity.flowerInPot);
+        if(block != null){
             GL11.glTranslatef((float)x, (float)y, (float)z);
-            Block block = Block.getBlock(tileEntity.flowerInPot);
             TextureRegistry.blockAtlas.bind();
             float scaleValue = 0.75F;
             GL11.glScalef(scaleValue, scaleValue, scaleValue);
             GL11.glTranslatef(0.66F, 0.75F, 0.66F);
-            float lightLevel = Minecraft.getMinecraft(this).theWorld.getLightBrightness(tileEntity.x, tileEntity.y, tileEntity.z);
+            float lightLevel = renderBlocks.getBlockBrightness(tileEntity.worldObj, tileEntity.x, tileEntity.y, tileEntity.z);
             if (Global.accessor.isFullbrightEnabled()) lightLevel = 1.0f;
             BlockModel.setRenderBlocks(renderBlocks);
             Integer lmc = null;
@@ -41,8 +55,18 @@ public class FlowerJarBlockEntityRenderer extends BlockEntityRenderer<FlowerJarB
                 } else {
                     lmc = tileEntity.worldObj.getLightmapCoord(tileEntity.x, tileEntity.y, tileEntity.z, 0);
                 }
+                lightLevel = 1f;
+            }
+            GL11.glEnable(GL_BLEND);
+            GL11.glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+            if (LightmapHelper.isLightmapEnabled()) { // TODO remove these awful hardcoded fixes
+                Lighting.enableInventoryLight();
             }
             BlockModelDispatcher.getInstance().getDispatch(block).renderBlockOnInventory(tessellator, tileEntity.flowerData, lightLevel, lmc);
+            GL11.glDisable(GL_BLEND);
+            if (LightmapHelper.isLightmapEnabled()) { // This one too
+                Lighting.disable();
+            }
         }
         GL11.glPopMatrix();
     }
diff --git a/src/main/java/net/minecraft/core/block/ActivatorBlock.java b/src/main/java/net/minecraft/core/block/ActivatorBlock.java
index 60a44ff0c..e13060116 100644
--- a/src/main/java/net/minecraft/core/block/ActivatorBlock.java
+++ b/src/main/java/net/minecraft/core/block/ActivatorBlock.java
@@ -89,10 +89,7 @@ public class ActivatorBlock extends VeryRotatableEntityBlock
     @Override
     public void updateTick(World world, int x, int y, int z, Random rand)
     {
-        if(getNeighborSignal(world, x, y, z, RotatableBlock.getDirectionFromMeta(world.getBlockMetadata(x, y, z))))
-        {
-            useItem(world, x, y, z, rand);
-        }
+        useItem(world, x, y, z, rand);
     }
 
     private boolean getNeighborSignal(World world, int x, int y, int z, Direction direction) {
diff --git a/src/main/java/net/minecraft/core/block/ButtonBlock.java b/src/main/java/net/minecraft/core/block/ButtonBlock.java
index d3eafa59f..e4a3b4cb7 100644
--- a/src/main/java/net/minecraft/core/block/ButtonBlock.java
+++ b/src/main/java/net/minecraft/core/block/ButtonBlock.java
@@ -126,7 +126,7 @@ public class ButtonBlock extends Block
                 break;
             case EAST:
                 if (world.isBlockNormalCube(x - 1, y, z)) {
-                    orientation = SIDE_EAST;
+                    orientation = SIDE_WEST;
                 }
                 break;
         }
@@ -169,7 +169,7 @@ public class ButtonBlock extends Block
                 break;
             case EAST:
                 if (world.isBlockNormalCube(x - 1, y, z)) {
-                    orientation = SIDE_EAST;
+                    orientation = SIDE_WEST;
                 }
                 break;
         }
diff --git a/src/main/java/net/minecraft/core/block/ChestBlock.java b/src/main/java/net/minecraft/core/block/ChestBlock.java
index 8c8ebeda5..da168c4c0 100644
--- a/src/main/java/net/minecraft/core/block/ChestBlock.java
+++ b/src/main/java/net/minecraft/core/block/ChestBlock.java
@@ -231,6 +231,37 @@ public class ChestBlock extends EntityBlock implements IPaintable {
 			}
 		}
 	}
+
+	public static void setDefaultDirection(World world, int x, int y, int z)
+	{
+		if(world.isClientSide)
+		{
+			return;
+		}
+		int bN = world.getBlockId(x, y, z - 1);
+		int bS = world.getBlockId(x, y, z + 1);
+		int bW = world.getBlockId(x - 1, y, z);
+		int bE = world.getBlockId(x + 1, y, z);
+		Direction direction = Direction.NORTH;
+		if(Block.solid[bN] && !Block.solid[bS])
+		{
+			direction = Direction.SOUTH;
+		}
+		if(Block.solid[bS] && !Block.solid[bN])
+		{
+			direction = Direction.NORTH;
+		}
+		if(Block.solid[bW] && !Block.solid[bE])
+		{
+			direction = Direction.EAST;
+		}
+		if(Block.solid[bE] && !Block.solid[bW])
+		{
+			direction = Direction.WEST;
+		}
+
+		world.setBlockMetadataWithNotify(x, y, z, getMetaWithType(getMetaWithDirection(world.getBlockMetadata(x, y, z), direction), Type.SINGLE));
+	}
 	
 	@Override
 	public void onNeighborBlockChange(World world, int x, int y, int z, int blockId) {
@@ -262,13 +293,13 @@ public class ChestBlock extends EntityBlock implements IPaintable {
 		}
 	}
 	
-	public void setType(World world, int x, int y, int z, Type type) {
+	public static void setType(World world, int x, int y, int z, Type type) {
 		if(isChest(world, x, y, z)) {
 			world.setBlockMetadataWithNotify(x, y, z, getMetaWithType(world.getBlockMetadata(x, y, z), type));
 		}
 	}
 	
-	public Direction getDirection(World world, int x, int y, int z) {
+	public static Direction getDirection(World world, int x, int y, int z) {
 		if(isChest(world, x, y, z)) {
 			return getDirectionFromMeta(world.getBlockMetadata(x, y, z));
 		}
diff --git a/src/main/java/net/minecraft/core/block/DispenserBlock.java b/src/main/java/net/minecraft/core/block/DispenserBlock.java
index fc358c38d..1cd953bfc 100644
--- a/src/main/java/net/minecraft/core/block/DispenserBlock.java
+++ b/src/main/java/net/minecraft/core/block/DispenserBlock.java
@@ -48,7 +48,7 @@ public class DispenserBlock extends VeryRotatableEntityBlock
     {
         Direction direction = VeryRotatableEntityBlock.metaToDirection(world.getBlockMetadata(x, y, z));
         int xOffset = direction.getOffsetX();
-        int yOffset = direction.getOffsetX();
+        int yOffset = direction.getOffsetY();
         int zOffset = direction.getOffsetZ();
 
         DispenserBlockEntity tileEntity = (DispenserBlockEntity)world.getBlockEntity(x, y, z);
@@ -97,7 +97,7 @@ public class DispenserBlock extends VeryRotatableEntityBlock
                 world.entityJoinedWorld(item);
                 world.playBlockEvent(LevelListener.EVENT_DISPENSER_ITEM, x, y, z, 0);
             }
-            world.playBlockEvent(LevelListener.EVENT_DISPENSER_PARTICLES, x, y, z, xOffset + 1 + (zOffset + 1) * 3);
+            world.playBlockEvent(LevelListener.EVENT_DISPENSER_PARTICLES, x, y, z, direction.getId());
         }
     }
 
@@ -118,10 +118,7 @@ public class DispenserBlock extends VeryRotatableEntityBlock
     @Override
 	public void updateTick(World world, int x, int y, int z, Random rand)
     {
-        if(world.hasNeighborSignal(x, y, z) || world.hasNeighborSignal(x, y + 1, z))
-        {
-            dispenseItem(world, x, y, z, rand);
-        }
+        dispenseItem(world, x, y, z, rand);
     }
 
     @Override
diff --git a/src/main/java/net/minecraft/core/block/RedstonePumpkinBlock.java b/src/main/java/net/minecraft/core/block/RedstonePumpkinBlock.java
index 6a0e2d5ce..aa728531d 100644
--- a/src/main/java/net/minecraft/core/block/RedstonePumpkinBlock.java
+++ b/src/main/java/net/minecraft/core/block/RedstonePumpkinBlock.java
@@ -29,7 +29,7 @@ public class RedstonePumpkinBlock extends RotatableBlock {
 
     @Override
     public boolean getDirectSignal(World world, int x, int y, int z, Side side) {
-        return getSignal(world, x, y, z, side.getOpposite());
+        return getSignal(world, x, y, z, side);
     }
 
     @Override
@@ -41,6 +41,11 @@ public class RedstonePumpkinBlock extends RotatableBlock {
         return mySide == side.getOpposite();
     }
 
+    @Override
+    public boolean isSignalSource() {
+        return true;
+    }
+
     @Override
     public int getPistonPushReaction(World world, int x, int y, int z) {
         return Material.PISTON_PUSHABLE;
diff --git a/src/main/java/net/minecraft/core/block/RotatableBlock.java b/src/main/java/net/minecraft/core/block/RotatableBlock.java
index af90e4f69..63379bdbd 100644
--- a/src/main/java/net/minecraft/core/block/RotatableBlock.java
+++ b/src/main/java/net/minecraft/core/block/RotatableBlock.java
@@ -34,4 +34,34 @@ public abstract class RotatableBlock extends Block{
         world.setBlockMetadataWithNotify(x, y, z, RotatableBlock.setDirection(0, side.getDirection()));
     }
 
+    public static void setDefaultDirection(World world, int x, int y, int z)
+    {
+        if(world.isClientSide)
+        {
+            return;
+        }
+        int bN = world.getBlockId(x, y, z - 1);
+        int bS = world.getBlockId(x, y, z + 1);
+        int bW = world.getBlockId(x - 1, y, z);
+        int bE = world.getBlockId(x + 1, y, z);
+        Direction direction = Direction.NORTH;
+        if(Block.solid[bN] && !Block.solid[bS])
+        {
+            direction = Direction.SOUTH;
+        }
+        if(Block.solid[bS] && !Block.solid[bN])
+        {
+            direction = Direction.NORTH;
+        }
+        if(Block.solid[bW] && !Block.solid[bE])
+        {
+            direction = Direction.EAST;
+        }
+        if(Block.solid[bE] && !Block.solid[bW])
+        {
+            direction = Direction.WEST;
+        }
+        world.setBlockMetadataWithNotify(x, y, z, setDirection(world.getBlockMetadata(x, y, z), direction));
+    }
+
 }
diff --git a/src/main/java/net/minecraft/core/block/TorchBlock.java b/src/main/java/net/minecraft/core/block/TorchBlock.java
index 62f15f2f5..b3ca58fc7 100644
--- a/src/main/java/net/minecraft/core/block/TorchBlock.java
+++ b/src/main/java/net/minecraft/core/block/TorchBlock.java
@@ -54,8 +54,7 @@ public class TorchBlock extends Block
 
     private boolean canPlaceOnTop(World world, int x, int y, int z)
     {
-    	int id = world.getBlockId(x, y, z);
-        return world.canPlaceOnSurfaceOfBlock(x, y, z) || id == Blocks.FENCE_PLANKS_OAK.id || id == Blocks.FENCE_PLANKS_OAK_PAINTED.id;
+        return canPlaceBlockAt(world, x, y, z);
     }
 
     @Override
@@ -77,12 +76,18 @@ public class TorchBlock extends Block
         {
             return true;
         }
-        return world.canPlaceOnSurfaceOfBlock(x, y - 1, z);
+        int blockBelow = world.getBlockId(x, y - 1, z);
+        return world.canPlaceOnSurfaceOfBlock(x, y - 1, z)
+            || blockBelow == Blocks.FENCE_PLANKS_OAK.id
+            || blockBelow == Blocks.FENCE_PLANKS_OAK_PAINTED.id
+            || blockBelow == Blocks.FENCE_CHAINLINK.id
+            || blockBelow == Blocks.FENCE_PAPER_WALL.id
+            || blockBelow == Blocks.FENCE_STEEL.id;
     }
 
     @Override
     public void onBlockPlacedByMob(World world, int x, int y, int z, @NotNull Side side, Mob mob, double xPlaced, double yPlaced) {
-        int orientation = SIDE_NONE;
+        int orientation = SIDE_BOTTOM;
         switch (side) {
             case TOP:
                 if(canPlaceOnTop(world, x, y - 1, z))
@@ -212,7 +217,13 @@ public class TorchBlock extends Block
                 invalid = !world.isBlockNormalCube(x, y, z + 1);
                 break;
             case SIDE_BOTTOM:
-                invalid = !world.isBlockNormalCube(x, y - 1, z);
+                int blockBelow = world.getBlockId(x, y - 1, z);
+                invalid = !(world.canPlaceOnSurfaceOfBlock(x, y - 1, z)
+                    || blockBelow == Blocks.FENCE_PLANKS_OAK.id
+                    || blockBelow == Blocks.FENCE_PLANKS_OAK_PAINTED.id
+                    || blockBelow == Blocks.FENCE_CHAINLINK.id
+                    || blockBelow == Blocks.FENCE_PAPER_WALL.id
+                    || blockBelow == Blocks.FENCE_STEEL.id);
                 break;
             default:
                 invalid = true;
diff --git a/src/main/java/net/minecraft/core/block/TrapDoorBlock.java b/src/main/java/net/minecraft/core/block/TrapDoorBlock.java
index 91b9becea..6c824e5a3 100644
--- a/src/main/java/net/minecraft/core/block/TrapDoorBlock.java
+++ b/src/main/java/net/minecraft/core/block/TrapDoorBlock.java
@@ -128,13 +128,16 @@ public class TrapDoorBlock extends Block {
             return;
         }
 
-        int meta = world.getBlockMetadata(x, y, z);
-        boolean isOpened = isTrapdoorOpen(meta);
-        boolean isPowered = world.hasNeighborSignal(x, y, z);
-
-        if (isOpened != isPowered) {
-            world.setBlockMetadataWithNotify(x, y, z, setTrapdoorOpen(meta, isPowered));
-            world.playBlockEvent(null, LevelListener.EVENT_DOOR_SOUND, x, y, z, 0);
+        Block block = Block.getBlock(blockId);
+        if (block == null || block.isSignalSource()) {
+            int meta = world.getBlockMetadata(x, y, z);
+            boolean isOpened = isTrapdoorOpen(meta);
+            boolean isPowered = world.hasNeighborSignal(x, y, z);
+
+            if (isOpened != isPowered) {
+                world.setBlockMetadataWithNotify(x, y, z, setTrapdoorOpen(meta, isPowered));
+                world.playBlockEvent(null, LevelListener.EVENT_DOOR_SOUND, x, y, z, 0);
+            }
         }
     }
 
diff --git a/src/main/java/net/minecraft/core/block/entity/SensorBlockEntity.java b/src/main/java/net/minecraft/core/block/entity/SensorBlockEntity.java
index 09423ec18..eb8c4c438 100644
--- a/src/main/java/net/minecraft/core/block/entity/SensorBlockEntity.java
+++ b/src/main/java/net/minecraft/core/block/entity/SensorBlockEntity.java
@@ -113,6 +113,7 @@ public class SensorBlockEntity extends BlockEntity {
 			List<Entity> list = world.getEntitiesWithinAABBExcludingEntity(null, detectionBox);
 			for(int i=0; i < list.size(); i++) {
 				Entity entity = list.get(i);
+				if (entity == holder) continue;
 				if(entity instanceof Player) {
 					Player player = (Player) entity;
 					player.triggerAchievement(Achievements.GET_SENSED);
diff --git a/src/main/java/net/minecraft/core/world/generate/feature/WorldFeatureDungeon.java b/src/main/java/net/minecraft/core/world/generate/feature/WorldFeatureDungeon.java
index 4a48328e6..62b47929f 100644
--- a/src/main/java/net/minecraft/core/world/generate/feature/WorldFeatureDungeon.java
+++ b/src/main/java/net/minecraft/core/world/generate/feature/WorldFeatureDungeon.java
@@ -2,6 +2,8 @@ package net.minecraft.core.world.generate.feature;
 
 import net.minecraft.core.WeightedRandomBag;
 import net.minecraft.core.WeightedRandomLootObject;
+import net.minecraft.core.block.ChestBlock;
+import net.minecraft.core.block.RotatableBlock;
 import net.minecraft.core.block.entity.ChestBlockEntity;
 import net.minecraft.core.block.entity.MobSpawnerBlockEntity;
 import net.minecraft.core.item.Item;
@@ -158,6 +160,7 @@ public class WorldFeatureDungeon extends WorldFeature
                     continue;
                 }
                 world.setBlockWithNotify(k3, l3, i4, Blocks.CHEST_PLANKS_OAK.id);
+                ChestBlock.setDefaultDirection(world, k3, l3, i4);
                 ChestBlockEntity tileentitychest = (ChestBlockEntity)world.getBlockEntity(k3, l3, i4);
                 int k4 = 0;
                 do
diff --git a/src/main/java/net/minecraft/core/world/generate/feature/WorldFeatureLabyrinth.java b/src/main/java/net/minecraft/core/world/generate/feature/WorldFeatureLabyrinth.java
index 5d56b987c..3a62fe44c 100644
--- a/src/main/java/net/minecraft/core/world/generate/feature/WorldFeatureLabyrinth.java
+++ b/src/main/java/net/minecraft/core/world/generate/feature/WorldFeatureLabyrinth.java
@@ -2,6 +2,8 @@ package net.minecraft.core.world.generate.feature;
 
 import net.minecraft.core.WeightedRandomBag;
 import net.minecraft.core.WeightedRandomLootObject;
+import net.minecraft.core.block.ChestBlock;
+import net.minecraft.core.block.RotatableBlock;
 import net.minecraft.core.block.entity.ChestBlockEntity;
 import net.minecraft.core.block.entity.DispenserBlockEntity;
 import net.minecraft.core.block.entity.MobSpawnerBlockEntity;
@@ -144,7 +146,9 @@ public class WorldFeatureLabyrinth extends WorldFeature
                         if (!generateTrapOnWall && (xWallCheck || zWallCheck)) {
                             if ((x == blockZ || z == blockZ) && y == blockY) {
                                 world.setBlockWithNotify(x, y, z, Blocks.MOTION_SENSOR_IDLE.id);
+                                RotatableBlock.setDefaultDirection(world, x, y, z);
                                 world.setBlockWithNotify(x, y - 1, z, Blocks.DISPENSER_COBBLE_STONE.id);
+                                RotatableBlock.setDefaultDirection(world, x, y - 1, z);
                                 DispenserBlockEntity tileEntityDispenser = (DispenserBlockEntity) world.getBlockEntity(x, blockY - 1, z);
                                 int k4 = 0;
                                 while (k4 < 3) {
@@ -373,6 +377,7 @@ public class WorldFeatureLabyrinth extends WorldFeature
         int chestZ = blockZ + random.nextInt(size-1) - (size-1);
         if(canReplace(world, chestX, blockY-2, chestZ)) {
             world.setBlockWithNotify(chestX, blockY - 1, chestZ, Blocks.CHEST_PLANKS_OAK.id);
+            ChestBlock.setDefaultDirection(world, chestX, blockY - 1, chestZ);
             ChestBlockEntity tileentitychest = (ChestBlockEntity) world.getBlockEntity(chestX, blockY - 1, chestZ);
             int k4 = 0;
             while (k4 < 10) {
diff --git a/src/main/resources/assets/minecraft/textures/block/block_diamond/bottom.png b/src/main/resources/assets/minecraft/textures/block/block_diamond/bottom.png
index bb1413d09..1e9558983 100644
Binary files a/src/main/resources/assets/minecraft/textures/block/block_diamond/bottom.png and b/src/main/resources/assets/minecraft/textures/block/block_diamond/bottom.png differ
diff --git a/src/main/resources/assets/minecraft/textures/block/block_diamond/side.png b/src/main/resources/assets/minecraft/textures/block/block_diamond/side.png
index 362366476..3ff53ebf9 100644
Binary files a/src/main/resources/assets/minecraft/textures/block/block_diamond/side.png and b/src/main/resources/assets/minecraft/textures/block/block_diamond/side.png differ
diff --git a/src/main/resources/assets/minecraft/textures/block/block_diamond/top.png b/src/main/resources/assets/minecraft/textures/block/block_diamond/top.png
index 6baa8777c..65ffa68f3 100644
Binary files a/src/main/resources/assets/minecraft/textures/block/block_diamond/top.png and b/src/main/resources/assets/minecraft/textures/block/block_diamond/top.png differ
diff --git a/src/main/resources/assets/minecraft/textures/block/block_gold/bottom.png b/src/main/resources/assets/minecraft/textures/block/block_gold/bottom.png
index 46c9338bf..4b3ac636d 100644
Binary files a/src/main/resources/assets/minecraft/textures/block/block_gold/bottom.png and b/src/main/resources/assets/minecraft/textures/block/block_gold/bottom.png differ
diff --git a/src/main/resources/assets/minecraft/textures/block/block_gold/side.png b/src/main/resources/assets/minecraft/textures/block/block_gold/side.png
index 0142f2db6..fec427dfa 100644
Binary files a/src/main/resources/assets/minecraft/textures/block/block_gold/side.png and b/src/main/resources/assets/minecraft/textures/block/block_gold/side.png differ
diff --git a/src/main/resources/assets/minecraft/textures/block/block_gold/top.png b/src/main/resources/assets/minecraft/textures/block/block_gold/top.png
index 9489269be..52e94b175 100644
Binary files a/src/main/resources/assets/minecraft/textures/block/block_gold/top.png and b/src/main/resources/assets/minecraft/textures/block/block_gold/top.png differ
diff --git a/src/main/resources/assets/minecraft/textures/block/block_iron/bottom.png b/src/main/resources/assets/minecraft/textures/block/block_iron/bottom.png
index 657bc285e..134f102f4 100644
Binary files a/src/main/resources/assets/minecraft/textures/block/block_iron/bottom.png and b/src/main/resources/assets/minecraft/textures/block/block_iron/bottom.png differ
diff --git a/src/main/resources/assets/minecraft/textures/block/block_iron/side.png b/src/main/resources/assets/minecraft/textures/block/block_iron/side.png
index e6d41008f..80b6723c3 100644
Binary files a/src/main/resources/assets/minecraft/textures/block/block_iron/side.png and b/src/main/resources/assets/minecraft/textures/block/block_iron/side.png differ
diff --git a/src/main/resources/assets/minecraft/textures/block/block_iron/top.png b/src/main/resources/assets/minecraft/textures/block/block_iron/top.png
index 9f9aef8cb..7b9139359 100644
Binary files a/src/main/resources/assets/minecraft/textures/block/block_iron/top.png and b/src/main/resources/assets/minecraft/textures/block/block_iron/top.png differ
diff --git a/src/main/resources/assets/minecraft/textures/block/block_steel/bottom.png b/src/main/resources/assets/minecraft/textures/block/block_steel/bottom.png
index 9ea6d2610..40c5e00ea 100644
Binary files a/src/main/resources/assets/minecraft/textures/block/block_steel/bottom.png and b/src/main/resources/assets/minecraft/textures/block/block_steel/bottom.png differ
diff --git a/src/main/resources/assets/minecraft/textures/block/block_steel/side.png b/src/main/resources/assets/minecraft/textures/block/block_steel/side.png
index c34b7373d..69bab0ce2 100644
Binary files a/src/main/resources/assets/minecraft/textures/block/block_steel/side.png and b/src/main/resources/assets/minecraft/textures/block/block_steel/side.png differ
diff --git a/src/main/resources/assets/minecraft/textures/block/block_steel/top.png b/src/main/resources/assets/minecraft/textures/block/block_steel/top.png
index 12e0e819c..72eea037c 100644
Binary files a/src/main/resources/assets/minecraft/textures/block/block_steel/top.png and b/src/main/resources/assets/minecraft/textures/block/block_steel/top.png differ
